@@ -3,7 +3,7 @@
 # reportbug - Report a bug in the Debian distribution.
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -23,10 +23,10 @@ ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS
 SOFTWARE."""
 
 __all__ = ['bugreport', 'utils', 'urlutils', 'checkbuildd', 'checkversions',
-           'debbugs', 'exceptions', 'submit', 'tempfile']
+           'debbugs', 'exceptions', 'submit', 'tempfile', 'mailer']
 
-VERSION_NUMBER = "7.6.0ubuntu1"
+VERSION_NUMBER = "7.7.0ubuntu1"
 
 VERSION = "reportbug " + VERSION_NUMBER
 COPYRIGHT = VERSION + '\nCopyright (C) 1999-2008 Chris Lawrence <lawrencc@debian.org>' + \
-                      '\nCopyright (C) 2008-2019 Sandro Tosi <morph@debian.org>'
+                      '\nCopyright (C) 2008-2020 Sandro Tosi <morph@debian.org>'
