@@ -2,7 +2,7 @@
 # bugreport module - object containing bug stuff for reporting
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -89,9 +89,16 @@ class bugreport(object):
         locinfo = []
         langsetting = os.environ.get('LANG', 'C')
         allsetting = os.environ.get('LC_ALL', '')
+        languagesetting = os.environ.get('LANGUAGE', '')
         for setting in ('LANG', 'LC_CTYPE', 'LANGUAGE'):
             if setting == 'LANG':
                 env = langsetting
+            elif setting == 'LANGUAGE':
+                if languagesetting:
+                    env = languagesetting
+                else:
+                    locinfo.append('LANGUAGE not set')
+                    continue
             else:
                 env = '%s (charmap=%s)' % (os.environ.get(setting, langsetting), subprocess.getoutput("locale charmap"))
 
@@ -161,11 +168,11 @@ class bugreport(object):
                 kinfo = []
 
                 if 'SMP' in un[3]:
-                    cores = os.cpu_count()
-                    if cores > 1:
-                        kinfo += ['SMP w/%d CPU cores' % cores]
-                    elif cores == 1:
-                        kinfo += ['SMP w/1 CPU core']
+                    threads = os.cpu_count()
+                    if threads > 1:
+                        kinfo += ['SMP w/%d CPU threads' % threads]
+                    elif threads == 1:
+                        kinfo += ['SMP w/1 CPU thread']
                 if 'PREEMPT' in un[3]:
                     kinfo += ['PREEMPT']
 
