@@ -3,7 +3,7 @@
 #
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -265,7 +265,7 @@ def handle_debian_ftp(package, bts, ui, fromaddr, timeout, online=True, http_pro
             section, priority = info[16], info[10]
 
     if tag == 'override':
-        headers.append('X-Debbugs-CC: debian-boot@lists.debian.org')
+        pseudos.append('X-Debbugs-Cc: debian-boot@lists.debian.org')
         ui.log_message('Your report will be carbon-copied to debian-boot.\n')
 
         # we handle here the override change request
@@ -340,7 +340,7 @@ def handle_debian_ftp(package, bts, ui, fromaddr, timeout, online=True, http_pro
             suite = 'unstable'
 
         if suite not in ('testing', 'unstable', 'experimental'):
-            headers.append('X-Debbugs-CC: debian-release@lists.debian.org')
+            pseudos.append('X-Debbugs-Cc: debian-release@lists.debian.org')
             ui.log_message('Your report will be carbon-copied to debian-release.\n')
 
         why = 'Please enter the reason for removal: '
@@ -610,7 +610,38 @@ def handle_debian_release(package, bts, ui, fromaddr, timeout, online=True, http
                 """ % (package, package, version))
     elif tag.endswith('-pu'):
         subject = '%s: package %s/%s' % (tag, package, version)
-        body = '(please explain the reason for this update here)\n'
+        body = textwrap.dedent("""\
+                (Please provide enough information to help the release team
+                to judge the request efficiently. E.g. by filling in the
+                sections below.)
+
+                [ Reason ]
+                (Explain what the reason for the (old-)stable update is. I.e.
+                what is the bug, when was it introduced, is this a regression
+                with respect to the previous (old-)stable.)
+
+                [ Impact ]
+                (What is the impact for the user if the update isn't approved?)
+
+                [ Tests ]
+                (What automated or manual tests cover the affected code?)
+
+                [ Risks ]
+                (Discussion of the risks involved. E.g. code is trivial or
+                complex, alternatives available.)
+
+                [ Checklist ]
+                  [ ] *all* changes are documented in the d/changelog
+                  [ ] I reviewed all changes and I approve them
+                  [ ] attach debdiff against the package in (old)stable
+                  [ ] the issue is verified as fixed in unstable
+
+                [ Changes ]
+                (Explain *all* the changes)
+
+                [ Other info ]
+                (Anything else the release team should know.)
+                """ % (package, package, version))
     elif tag == 'rm':
         subject = 'RM: %s/%s' % (package, version)
         body = '(explain the reason for the removal here)\n'
@@ -701,7 +732,7 @@ def handle_wnpp(package, bts, ui, fromaddr, timeout, online=True, http_proxy=Non
                 'appropriate short description for the eventual package: ')
 
         if tag == 'ITP':
-            headers.append('X-Debbugs-CC: debian-devel@lists.debian.org')
+            pseudos.append('X-Debbugs-Cc: debian-devel@lists.debian.org')
             pseudos.append('Owner: {}'.format(
                 email.header.make_header(email.header.decode_header(fromaddr))))
             ui.log_message('Your report will be carbon-copied to debian-devel, '
@@ -734,7 +765,7 @@ def handle_wnpp(package, bts, ui, fromaddr, timeout, online=True, http_proxy=Non
             severity = 'important'
 
         if tag == 'RFH':
-            headers.append('X-Debbugs-CC: debian-devel@lists.debian.org')
+            pseudos.append('X-Debbugs-Cc: debian-devel@lists.debian.org')
             ui.log_message('Your request will be carbon-copied to debian-devel, '
                            'per Debian policy.\n')
 
@@ -846,6 +877,7 @@ TAGS = {
     'l10n': 'This bug reports a localization/internationalization issue.',
     'a11y': 'This bug is relevant to the accessibility of the package.',
     'newcomer': 'This bug has a known solution but the maintainer requests someone else implement it.',
+    'ftbfs': 'The package fails to build from source.',
 }
 
 
@@ -1091,16 +1123,29 @@ def get_reports(package, timeout, system='debian', mirrors=None, version=None,
         if isinstance(package, str):
             if source:
                 bugs = debianbts.get_bugs(src=package)
+                bugs += debianbts.get_bugs(affects='src:'+package)
             else:
                 bugs = debianbts.get_bugs(package=package)
+                bugs += debianbts.get_bugs(affects=package)
         else:
-            bugs = list(map(int, package))
+            bugs = []
+            for pkg in package:
+                try:
+                    bugs += [ int(pkg) ]
+                except ValueError:
+                    if pkg.startswith('src:'):
+                        bugs += debianbts.get_bugs(src=pkg[4:])
+                        bugs += debianbts.get_bugs(affects=pkg)
+                    elif source:
+                        bugs += debianbts.get_bugs(src=pkg)
+                        bugs += debianbts.get_bugs(affects='src:'+pkg)
+                    else:
+                        bugs += debianbts.get_bugs(package=pkg)
+                        bugs += debianbts.get_bugs(affects=pkg)
 
-        try:
-            # retrieve bugs and generate the hierarchy
-            stats = debianbts.get_status(bugs)
-        except:
-            raise QuertBTSError
+        bugs = list(set(bugs))
+        # retrieve bugs and generate the hierarchy
+        stats = debianbts.get_status(bugs)
 
         d = defaultdict(list)
         for s in stats:
