@@ -1,7 +1,7 @@
 # reportbug_submit module - email and GnuPG functions
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2006 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -357,6 +357,10 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
                 # submit
                 if smtphost.lower() == 'reportbug.debian.org':
                     conn = smtplib.SMTP(smtphost, 587)
+                elif smtphost.endswith(':465'):
+                    # ignore smtptls setting since port 465 implies SSL
+                    smtptls = None
+                    conn = smtplib.SMTP_SSL(smtphost)
                 else:
                     conn = smtplib.SMTP(smtphost)
                 response = conn.ehlo()
@@ -430,11 +434,11 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
                             'saved to %s\n', msgname)
 
     if mua:
-        ewrite("Spawning %s...\n", mua.name)
+        ewrite("Spawning %s...\n", mua.executable)
         returnvalue = 0
         succeeded = False
         while not succeeded:
-            returnvalue = mua.send(filename)
+            returnvalue = ui.system(mua.get_send_command(filename, attachments))
             if returnvalue != 0:
                 ewrite("Mutt users should be aware it is mandatory to edit the draft before sending.\n")
                 mtitle = 'Report has not been sent yet; what do you want to do now?'
@@ -447,7 +451,7 @@ def send_report(body, attachments, mua, fromaddr, sendto, ccaddr, bccaddr,
                     fh, msgname = TempFile(prefix=tfprefix, dir=draftpath)
                     fh.write(message)
                     fh.close()
-                    ewrite('Draft saved into %s\n', msgname)
+                    ui.long_message('Draft saved into %s\n', msgname)
                     succeeded = True
             else:
                 succeeded = True
