@@ -62,7 +62,7 @@ from queue import Queue
 import threading
 import textwrap
 
-from reportbug.exceptions import NoPackage, NoBugs
+from reportbug.exceptions import NoPackage, NoBugs, QuertBTSError
 from reportbug import debbugs
 from reportbug.urlutils import launch_browser
 
@@ -89,7 +89,7 @@ def _assert_context(expected):
     # This compares by pointer value of the underlying GMainContext
     if really != expected:
         raise AssertionError('Function should be called in %s but was called in %s' %
-                             (_describe_context(really), _describe_context(expected)))
+                             (_describe_context(expected), _describe_context(really)))
 
     if not really.is_owner():
         raise AssertionError('Function should be called with %s acquired')
@@ -133,15 +133,6 @@ def info_dialog(message):
     dialog.show_all()
 
 
-def error_dialog(message):
-    _assert_context(ui_context)
-    dialog = Gtk.MessageDialog(assistant, Gtk.DialogFlags.MODAL | Gtk.DialogFlags.DESTROY_WITH_PARENT,
-                               Gtk.MessageType.ERROR, Gtk.ButtonsType.CLOSE, message)
-    dialog.connect('response', lambda d, *args: d.destroy())
-    dialog.set_title('Reportbug')
-    dialog.show_all()
-
-
 class CustomDialog(Gtk.Dialog):
     def __init__(self, stock_image, message, buttons, *args, **kwargs):
         _assert_context(ui_context)
@@ -266,7 +257,7 @@ class ReportViewerDialog(Gtk.Dialog):
         # maybe adding it as a secondary button or such is better
         if res == Gtk.ResponseType.APPLY:
             clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-            clipboard.set_text(self.message)
+            clipboard.set_text(self.message, -1)
         else:
             self.destroy()
 
@@ -495,7 +486,10 @@ class BugPage(Gtk.EventBox, threading.Thread):
         self.assistant.forward_page()
         # Though we're only a page, we are authorized to destroy our parent :)
         # This would be better handled connecting externally to self.reply_button
-        self.dialog.destroy()
+        try:
+            self.dialog.destroy()
+        except AttributeError:
+            pass
 
 
 class BugsDialog(Gtk.Dialog):
@@ -587,7 +581,7 @@ class ReportbugApplication(threading.Thread):
 
 
 # Connection with reportbug
-# Syncronize "pipe" with reportbug
+# Synchronize "pipe" with reportbug
 class SyncReturn(RuntimeError):
     def __init__(self, result):
         _assert_context(reportbug_context)
@@ -661,6 +655,8 @@ class Page(ReportbugConnector):
         self.assistant.set_page_side_image(self.widget, GdkPixbuf.Pixbuf.new_from_file(self.side_image))
         self.assistant.set_next_page(self)
         self.set_page_title("Reportbug")
+        # reportbug cannot usefully go back
+        self.assistant.commit()
 
     # Setup keyboard focus in the page
     def setup_focus(self):
@@ -710,7 +706,7 @@ class IntroPage(Page):
 
 This wizard will guide you through the bug reporting process step by step.
 
-<b>Note:</b> bug reports are publicly archived(including the email address of the submitter).""")
+<b>Note:</b> bug reports are publicly archived (including the email address of the submitter).""")
         label.set_use_markup(True)
         label.set_line_wrap(True)
         label.set_justify(Gtk.Justification.FILL)
@@ -1030,7 +1026,7 @@ class HandleBTSQueryPage(TreePage):
         root = sysinfo.get('btsroot')
         if not root:
             # do we need to make a dialog for this?
-            return
+            raise SyncReturn(None)
 
         if isinstance(package, str):
             pkgname = package
@@ -1047,9 +1043,9 @@ class HandleBTSQueryPage(TreePage):
             (count, sectitle, hierarchy) = debbugs.get_reports(
                 package, timeout, bts, mirrors=mirrors, version=version,
                 http_proxy=http_proxy, archived=archived, source=source)
-        except:
-            error_dialog("Unable to connect to %s BTS." % sysinfo['name'])
-            raise NoBugs
+        except Exception as e:
+            errmsg = 'Unable to connect to %s BTS (error: "%s"); ' % (debbugs.SYSTEMS[bts]['name'], repr(e))
+            raise QuertBTSError(errmsg)
 
         try:
             if not count:
@@ -1076,7 +1072,6 @@ class HandleBTSQueryPage(TreePage):
                 return(report, sectitle), {}
 
         except NoPackage:
-            error_dialog('No record of this package found.')
             raise NoPackage
 
         raise SyncReturn(None)
@@ -1188,7 +1183,7 @@ class HandleBTSQueryPage(TreePage):
 
     def execute(self, buglist, sectitle):
         _assert_context(ui_context)
-        GLib.idle_add(self.label.set_text, "%s. Double-click a bug to retrieve and submit more information." % sectitle)
+        GLib.idle_add(self.label.set_text, "%s. Double-click a bug to retrieve and submit more information, or press 'Next' if none match." % sectitle)
 
         self.model = Gtk.TreeStore(*([str] * len(self.columns)))
         for category in buglist:
@@ -1292,7 +1287,7 @@ class FinalMessagePage(LongMessagePage):
     def execute(self, *args, **kwargs):
         _assert_context(ui_context)
         LongMessagePage.execute(self, *args, **kwargs)
-        self.set_page_title("Thanks for your report")
+        #self.set_page_title("Thanks for your report")
 
 
 class EditorPage(Page):
