@@ -1,7 +1,7 @@
 # Text user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2001-08 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -38,7 +38,7 @@ except ImportError:
 
 from reportbug import debbugs, hiermatch
 from reportbug.exceptions import (
-    NoReport, NoPackage, NoBugs, NoNetwork,
+    NoReport, NoPackage, NoBugs, NoNetwork, QuertBTSError,
     InvalidRegex,
 )
 from reportbug.urlutils import launch_browser
@@ -100,7 +100,7 @@ def indent_wrap_text(text, starttext='', indent=0, linelen=None):
 if readline is not None:
     readline.parse_and_bind("tab: complete")
     try:
-        # minimize the word delimeter list if possible
+        # minimize the word delimiter list if possible
         readline.set_completer_delims(' ')
     except:
         pass
@@ -452,8 +452,8 @@ def show_report(number, system, mirrors,
 
         if not skip_pager:
             try:
-                with os.popen('sensible-pager', 'w') as fd:
-                    fd.write(text)
+                with subprocess.Popen('sensible-pager', stdin=subprocess.PIPE, errors='ignore') as fd:
+                    fd.communicate(text)
             except IOError as x:
                 if x.errno == errno.EPIPE:
                     pass
@@ -528,14 +528,8 @@ def handle_bts_query(package, bts, timeout, mirrors=None, http_proxy="",
             package, timeout, bts, mirrors=mirrors, version=version,
             source=source, http_proxy=http_proxy, archived=archived)
     except Exception as e:
-        ewrite('Unable to connect to %s BTS (error: "%s"); ' % (debbugs.SYSTEMS[bts]['name'], repr(e)))
-        res = select_options('continue', 'yN',
-                             {'y': 'Keep going.',
-                              'n': 'Abort.'})
-        if res == 'n':
-            raise NoNetwork
-        else:
-            raise NoBugs
+        errmsg = 'Unable to connect to %s BTS (error: "%s"); ' % (debbugs.SYSTEMS[bts]['name'], repr(e))
+        raise QuertBTSError(errmsg)
 
     try:
         # If there's no report, then skip all the rest
@@ -598,8 +592,8 @@ def handle_bts_query(package, bts, timeout, mirrors=None, http_proxy="",
             ewrite('%d bug reports found:\n\n', count)
 
         return browse_bugs(hierarchy, count, bugs, bts, queryonly,
-                           mirrors, http_proxy, timeout, screen, title, package,
-                           mbox_reader_cmd)
+                           mirrors, http_proxy, timeout, screen, title,
+                           package, source, mbox_reader_cmd)
 
     except NoPackage:
         long_message('No record of this package found.')
@@ -607,7 +601,8 @@ def handle_bts_query(package, bts, timeout, mirrors=None, http_proxy="",
 
 
 def browse_bugs(hierarchy, count, bugs, bts, queryonly, mirrors,
-                http_proxy, timeout, screen, title, package, mbox_reader_cmd):
+                http_proxy, timeout, screen, title, package,
+                source, mbox_reader_cmd):
     try:
         output_encoding = locale.getpreferredencoding()
     except locale.Error as msg:
@@ -687,7 +682,10 @@ def browse_bugs(hierarchy, count, bugs, bts, queryonly, mirrors,
                         lastpage = []
                         break
                     elif x == 'b':
-                        launch_browser('https://bugs.debian.org/%s' % package)
+                        if source:
+                            launch_browser('https://bugs.debian.org/src:%s' % package)
+                        else:
+                            launch_browser('https://bugs.debian.org/%s' % package)
                         continue
                     elif x == 'r':
                         continue
@@ -1008,8 +1006,8 @@ def display_report(text, use_pager=True, presubj=False):
 
     pager = os.environ.get('PAGER', 'sensible-pager')
     try:
-        with os.popen(pager, 'w') as p:
-            p.write(text)
+        with subprocess.Popen(pager, stdin=subprocess.PIPE, errors='ignore') as p:
+            p.communicate(text)
     except IOError:
         pass
 
