@@ -1,7 +1,7 @@
 # urwid user interface for reportbug
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 2006-08 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -23,12 +23,13 @@
 # (LGPL) Version 2.1 or later.  On Debian systems, this license is available
 # in /usr/share/common-licenses/LGPL
 
+import locale
 import sys
 import re
 import getpass
 from reportbug.exceptions import (
     UINotImportable,
-    NoPackage, NoBugs, NoReport,
+    NoPackage, NoBugs, NoReport, QuertBTSError,
 )
 from reportbug.urlutils import launch_browser
 from .text_ui import (
@@ -271,7 +272,7 @@ class listdialog(dialog):
 class checklistdialog(listdialog):
     def on_exit(self, exitcode):
         """
-        Mimick dialog(1)'s --checklist exit.
+        Mimic dialog(1)'s --checklist exit.
         Put each checked item in double quotes with a trailing space.
         """
         if exitcode:
@@ -338,7 +339,9 @@ display_failure = long_message
 
 def select_options(msg, ok, help=None, allow_numbers=False, nowrap=False,
                    ui=None, title=None):
-    box = dialog('', long_message=msg, height=('relative', 80),
+    loc = locale.nl_langinfo(locale.CODESET)
+    safe_msg = msg.encode(loc, errors='replace').decode(errors='replace')
+    box = dialog('', long_message=safe_msg, height=('relative', 80),
                  title=title or VERSION)
     if not help:
         help = {}
@@ -581,9 +584,8 @@ def handle_bts_query(package, bts, timeout, mirrors=None, http_proxy="",
             http_proxy=http_proxy, archived=archived, source=source)
     except Exception as e:
         ui.run_wrapper(nullfunc)
-        long_message('Unable to connect to %s BTS.', sysinfo['name'],
-                     title=title)
-        raise NoBugs
+        errmsg = 'Unable to connect to %s BTS (error: "%s"); ' % (sysinfo['name'], repr(e))
+        raise QuertBTSError(errmsg)
 
     try:
         if not count:
@@ -650,8 +652,8 @@ def handle_bts_query(package, bts, timeout, mirrors=None, http_proxy="",
         long_message('No record of this package found.', title=title)
         raise NoPackage
 
-    # we didn't find a report; we access Bugreport thru debbugs,
-    # so to avoid and import of debianbts
+    # we didn't find a report; we access Bugreport through debbugs,
+    # so to avoid an import of debianbts
     if result and not isinstance(result, debbugs.debianbts.Bugreport):
         raise NoReport
 
