@@ -3,7 +3,7 @@
 #
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -104,6 +104,18 @@ _opener = None
 
 
 def urlopen(url, proxies=None, timeout=60, data=None):
+    """Fetch an URL.
+
+    :param url:
+
+        The URL to open, e.g. ``"http://example.com/"``.
+
+    :returns:
+
+        The contents returned by invoking GET on the given URL, as a
+        Unicode string, e.g. ``u"Hello"``.
+
+    """
     global _opener
 
     if not proxies:
@@ -112,7 +124,7 @@ def urlopen(url, proxies=None, timeout=60, data=None):
     headers = {'User-Agent': UA_STR,
                'Accept-Encoding': 'gzip;q=1.0, deflate;q=0.9, identity;q=0.5'}
 
-    return requests.get(url, headers).text
+    return requests.get(url, headers=headers, proxies=proxies, timeout=timeout).text
 
     # req = urllib.request.Request(url, data, headers)
     #
@@ -139,6 +151,25 @@ def urlopen(url, proxies=None, timeout=60, data=None):
 # Global useful URL opener; returns None if the page is absent, otherwise
 # like urlopen
 def open_url(url, http_proxy=None, timeout=60):
+    """:param url:
+
+        The URL to open, e.g. ``"http://example.org/"``.
+
+    :param http_proxy:
+
+        The proxy to use for the http protocol.  By default, use the
+        :func:`urllib.request.getproxies()` settings.
+
+    :param timeout:
+
+        Socket timeout, in seconds.
+
+    :returns:
+
+        The contents returned by invoking GET on the given URL, as a
+        Unicode string, e.g. ``u"Hello"``.
+
+    """
     # Set timeout to 60 secs (1 min), cfr bug #516449
     # in #572316 we set a user-configurable timeout
     socket.setdefaulttimeout(timeout)
