@@ -2,7 +2,7 @@
 # utils module - common functions for reportbug UIs
 #   Written by Chris Lawrence <lawrencc@debian.org>
 #   Copyright (C) 1999-2008 Chris Lawrence
-#   Copyright (C) 2008-2019 Sandro Tosi <morph@debian.org>
+#   Copyright (C) 2008-2020 Sandro Tosi <morph@debian.org>
 #
 # This program is freely distributable per the following license:
 #
@@ -36,13 +36,15 @@ except ImportError as e:
         sys.exit(1)
 import shlex
 import email
+import email.policy
 import socket
 import subprocess
-import pipes
 import apt
 import gzip
+import urllib
 
 from .urlutils import open_url
+from .mailer import MUA
 
 # Paths for dpkg
 DPKGLIB = '/var/lib/dpkg'
@@ -52,7 +54,7 @@ STATUSDB = os.path.join(DPKGLIB, 'status')
 # Headers other than these become email headers for debbugs servers
 PSEUDOHEADERS = ('Package', 'Source', 'Version', 'Severity', 'File', 'Tags',
                  'Justification', 'Followup-For', 'Owner', 'User', 'Usertags',
-                 'Forwarded', 'Control')
+                 'Forwarded', 'Control', 'X-Debbugs-Cc')
 # These pseudo-headers can be repeated in the report
 REPEATABLE_PSEUDOHEADERS = ['Control',]
 
@@ -73,7 +75,7 @@ del mode
 # moved here since it needs the MODE_* vars to be defined
 from . import debbugs
 # it needs to be imported after debbugs
-from .ui import text_ui as ui
+#from .ui import text_ui as ui
 
 from reportbug.ui import AVAILABLE_UIS
 
@@ -103,6 +105,7 @@ CODENAME2SUITE = {'wheezy': 'oldoldoldstable',
                   'experimental': 'experimental'}
 SUITE2CODENAME = dict([(suite, codename) for codename, suite in list(CODENAME2SUITE.items())])
 
+_apt_cache = apt.Cache()
 
 def realpath(filename):
     filename = os.path.abspath(filename)
@@ -173,7 +176,7 @@ def glob_escape(filename):
 
 
 def search_pipe(searchfile, use_dlocate=True):
-    arg = pipes.quote(searchfile)
+    arg = shlex.quote(searchfile)
     if use_dlocate and os.path.exists('/usr/bin/dlocate'):
         pipe = os.popen('COLUMNS=79 dlocate -S %s 2>/dev/null' % arg)
     else:
@@ -215,7 +218,14 @@ def query_dpkg_for(filename, use_dlocate=True):
     pipe.close()
     # Try again without dlocate if no packages found
     if not packages and dlocate_used:
-        return query_dpkg_for(filename, use_dlocate=False)
+        _, packages = query_dpkg_for(filename, use_dlocate=False)
+
+    # still not found?
+    # dpkg and merged /usr do not work well together
+    if not packages and filename.startswith(('/usr/bin', '/usr/lib', '/usr/sbin')):
+        # try without '/usr'
+        filename = filename[4:]
+        return query_dpkg_for(filename)
 
     return filename, packages
 
@@ -361,7 +371,7 @@ def get_package_status(package, avail=False):
     except OSError:
         os.chdir('/')
 
-    packarg = pipes.quote(package)
+    packarg = shlex.quote(package)
     if avail:
         output = get_command_output(
             "LC_ALL=C.UTF-8 apt-cache show %s 2>/dev/null" % packarg)
@@ -533,14 +543,13 @@ def get_avail_database():
 
 
 def get_source_name(package):
-    packages = []
-
-    data = get_command_output('apt-cache showsrc ' + pipes.quote(package))
-    packre = re.compile(r'^Package: (.*)$')
-    for line in data.split('\n'):
-        m = packre.match(line)
-        if m:
-            return m.group(1)
+    try:
+        return _apt_cache[package].versions[0].source_name
+    except KeyError:
+        pass
+    # check if there is a source package with that name
+    if apt.apt_pkg.SourceRecords().lookup(package):
+        return package
     return None
 
 
@@ -549,9 +558,7 @@ def get_source_package(package):
     retlist = []
     found = {}
 
-    apt_cache = apt.Cache()
-
-    data = get_command_output('apt-cache showsrc ' + pipes.quote(package))
+    data = get_command_output('apt-cache showsrc ' + shlex.quote(package))
     binre = re.compile(r'^Binary: (.*)$')
     for line in data.split('\n'):
         m = binre.match(line)
@@ -562,7 +569,7 @@ def get_source_package(package):
 
     for p in packages:
         try:
-            desc = apt_cache[p].versions[0].summary
+            desc = _apt_cache[p].versions[0].summary
         except KeyError:
             continue
         if desc and (p not in found):
@@ -724,7 +731,7 @@ def get_changed_config_files(conffiles, nocompress=False):
             confinfo[filename] = msg
             continue
 
-        filemd5 = get_command_output('md5sum ' + pipes.quote(filename)).split()[0]
+        filemd5 = get_command_output('md5sum ' + shlex.quote(filename)).split()[0]
         if filemd5 == md5sum:
             continue
 
@@ -799,6 +806,13 @@ def lsb_release_info():
 
 
 def get_arch():
+    """Get the architecture of the current system.
+
+    :returns:
+
+        The architecture, e.g. ``"i386"``.
+
+    """
     arch = get_command_output('COLUMNS=79 dpkg --print-architecture 2>/dev/null').strip()
     if not arch:
         un = os.uname()
@@ -859,117 +873,6 @@ CONFIG_ARGS = (
     'paranoid', 'mbox_reader_cmd', 'max_attachment_size', 'listccme', 'outfile')
 
 
-class Mua:
-    command = ""
-    name = ""
-
-    def __init__(self, command):
-        self.command = command
-        self.name = command.split()[0]
-
-    def send(self, filename):
-        mua = self.command
-        if '%s' not in mua:
-            mua += ' %s'
-        return ui.system(mua % pipes.quote(filename))
-
-    def get_name(self):
-        return self.name
-
-
-class Gnus(Mua):
-    name = "gnus"
-
-    def __init__(self):
-        pass
-
-    def send(self, filename):
-        elisp = """(progn
-                      (load-file "/usr/share/reportbug/reportbug.el")
-                      (tfheen-reportbug-insert-template "%s"))"""
-        filename = re.sub("[\"\\\\]", "\\\\\\g<0>", filename)
-        elisp = pipes.quote(elisp % filename)
-        return ui.system("emacsclient --no-wait --eval %s 2>/dev/null"
-                         " || emacs --eval %s" % (elisp, elisp))
-
-
-MUA = {
-    'mutt': Mua('mutt -H'),
-    'mh': Mua('/usr/bin/mh/comp -use -file'),
-    'gnus': Gnus(),
-    'claws-mail': Mua('claws-mail --compose-from-file'),
-}
-MUA['nmh'] = MUA['mh']
-
-# TODO: convert them to class methods
-MUAVERSION = {
-    MUA['mutt']: 'mutt -v',
-    MUA['mh']: '/usr/bin/mh/comp -use -file',
-    MUA['gnus']: 'emacs --version',
-    MUA['claws-mail']: 'claws-mail --version',
-}
-
-
-def mua_is_supported(mua):
-    # check if the mua is supported by reportbug
-    if mua == 'mh' or mua == MUA['mh']:
-        mua_tmp = 'mh'
-    elif mua == 'nmh' or mua == MUA['nmh']:
-        mua_tmp = 'mh'
-    elif mua == 'gnus' or mua == MUA['gnus']:
-        mua_tmp = 'gnus'
-    elif mua == 'mutt' or mua == MUA['mutt']:
-        mua_tmp = 'mutt'
-    elif mua == 'claws-mail' or mua == MUA['claws-mail']:
-        mua_tmp = 'claws-mail'
-    else:
-        mua_tmp = mua
-    if mua_tmp not in MUA:
-        return False
-    else:
-        return True
-
-
-def mua_exists(mua):
-    # check if the mua is available on the system
-    if mua == 'mh' or mua == MUA['mh']:
-        mua_tmp = MUA['mh']
-    elif mua == 'nmh' or mua == MUA['nmh']:
-        mua_tmp = MUA['mh']
-    elif mua == 'gnus' or mua == MUA['gnus']:
-        mua_tmp = MUA['gnus']
-    elif mua == 'mutt' or mua == MUA['mutt']:
-        mua_tmp = MUA['mutt']
-    elif mua == 'claws-mail' or mua == MUA['claws-mail']:
-        mua_tmp = MUA['claws-mail']
-    else:
-        mua_tmp = MUA[mua]
-    output = '/dev/null'
-    if os.path.exists(output):
-        try:
-            returnvalue = subprocess.call(MUAVERSION[mua_tmp],
-                                          stdout=open(output, 'w', errors='backslashreplace'),
-                                          stderr=subprocess.STDOUT,
-                                          shell=True)
-        except (IOError, OSError):
-            returnvalue = subprocess.call(MUAVERSION[mua_tmp], shell=True)
-    else:
-        returnvalue = subprocess.call(MUAVERSION[mua_tmp], shell=True)
-    # 127 is the shell standard return value to indicate a 'command not found' result
-    if returnvalue == 127:
-        return False
-    else:
-        return True
-
-
-def mua_name(mua):
-    # in case the user specifies only the mua name in --mua, returns the default options
-    if mua in MUA:
-        return MUA[mua]
-    else:
-        return mua
-
-
 def first_run():
     return not os.path.exists(USERFILE)
 
@@ -1096,95 +999,105 @@ def parse_bug_control_file(filename):
     return submitas, submitto, reportwith, supplemental
 
 
-def cleanup_msg(dmessage, headers, pseudos, type):
-    pseudoheaders = []
-    # Handle non-pseduo-headers
+def cleanup_msg(dmessage, headers, pseudos, btstype):
+    newheaders = []
+    collected_pseudoheaders = []
+    clean_pseudoheaders = []
     headerre = re.compile(r'^([^:]+):\s*(.*)$', re.I)
-    newsubject = message = ''
+    message = ''
     parsing = lastpseudo = True
 
     # Include the headers that were passed in too!
-    newheaders = []
     for header in headers:
         mob = headerre.match(header)
         if mob:
             newheaders.append(mob.groups())
 
-    # Get the pseudo-headers fields
-    PSEUDOS = []
+    # we normalize pseudoheader keys
+    def normph(aph):
+        return '-'.join([x.capitalize() for x in aph.split('-')])
+
+    accepted_pseudoheaders = [normph(ph) for ph in PSEUDOHEADERS]
+
+    # Get the pseudo-header fields
     for ph in pseudos:
         mob = headerre.match(ph)
         if mob:
-            PSEUDOS.append(mob.group(1))
+            ph = normph(mob.group(1))
+            if ph not in accepted_pseudoheaders:
+                accepted_pseudoheaders.append(ph)
 
+    # look through the dirty message and extract headers and pseudoheaders
     for line in dmessage.split(os.linesep):
-        if not line and parsing:
-            parsing = False
-        elif parsing:
+        if parsing:
+            # stop trying to parse (pseudo-)headers at the first empty line
+            if not line:
+                parsing = False
+                continue
+
             mob = headerre.match(line)
             # GNATS and debbugs have different ideas of what a pseudoheader
             # is...
-            if mob and ((type == 'debbugs' and
-                                 mob.group(1) not in PSEUDOHEADERS and
-                                 mob.group(1) not in PSEUDOS) or
-                        (type == 'gnats' and mob.group(1)[0] != '>')):
+            if mob and ((btstype == 'debbugs' and
+                                 normph(mob.group(1)) not in accepted_pseudoheaders) or
+                        (btstype == 'gnats' and mob.group(1)[0] != '>')):
+                # unrecognized pseudoheaders are turned into headers
                 newheaders.append(mob.groups())
                 lastpseudo = False
-                continue
             elif mob:
-                # Normalize pseudo-header
-                lastpseudo = False
+                # Continuation lines are not supported for pseudoheaders
+                lastpseudo = True
+                # Normalize pseudo-header for debbugs, leave as is for
+                # gnats
                 key, value = mob.groups()
                 if key[0] != '>':
-                    # Normalize hyphenated headers to capitalize each word
-                    key = '-'.join([x.capitalize() for x in key.split('-')])
-                pseudoheaders.append((key, value))
-            elif not lastpseudo and len(newheaders):
+                    key = normph(key)
+                collected_pseudoheaders.append((key, value))
+            elif not lastpseudo and len(newheaders) and line[0] == ' ':
                 # Assume we have a continuation line
                 lastheader = newheaders[-1]
                 newheaders[-1] = (lastheader[0], lastheader[1] + '\n' + line)
-                continue
             else:
-                # Permit bogus headers in the pseudoheader section
-                headers.append(re.split(r':\s+', line, 1))
+                # Discard anything else found in the (pseudo-)header section
+                pass
         elif line.strip() != NEWBIELINE:
             message += line + '\n'
 
-    ph = []
-    if type == 'gnats':
-        for header, content in pseudoheaders:
+    if btstype == 'gnats':
+        for header, content in collected_pseudoheaders:
             if content:
-                ph += ["%s: %s" % (header, content)]
+                clean_pseudoheaders += ["%s: %s" % (header, content)]
             else:
-                ph += [header]
-    else:
-        ph2 = {}
-        repeatable_ph = []
-        # generate a list of pseudoheaders, but without duplicates
-        # we take the list of pseudoheaders defined in reportbug and add
-        # the ones passed by the user (if not already present). We are not using
-        # set(..) because we want to preserve the item order of PSEUDOHEADERS
-        pseudo_list = list(PSEUDOHEADERS)
-        for p in PSEUDOS:
-            if p not in pseudo_list:
-                pseudo_list.append(p)
+                clean_pseudoheaders += [header]
 
-        for header, content in pseudoheaders:
-            # if either in the canonical pseudo-headers list or in those passed on the command line
-            if header in pseudo_list:
-                if header not in REPEATABLE_PSEUDOHEADERS:
-                    ph2[header] = content
-                else:
-                    repeatable_ph += ['%s: %s' % (header, content)]
-            else:
-                newheaders.append((header, content))
+        return message, newheaders, clean_pseudoheaders
 
-        for header in pseudo_list:
-            if header in ph2:
-                ph += ['%s: %s' % (header, ph2[header])]
-        ph.extend(repeatable_ph)
+    # else btstype is debbugs:
+    unique_ph = {}
+    repeatable_ph = []
 
-    return message, newheaders, ph
+    for header, content in collected_pseudoheaders:
+        if header in REPEATABLE_PSEUDOHEADERS:
+            # repeatables can append
+            repeatable_ph += ['%s: %s' % (header, content)]
+            continue
+
+        # non-repeatables
+        if header == 'X-Debbugs-Cc' and header in unique_ph:
+            unique_ph[header] += ', ' + content
+        else:
+            # for most non-repeatables, the last overwrites the
+            # previous
+            unique_ph[header] = content
+
+    # sort pseudoheaders
+    for header in accepted_pseudoheaders:
+        if header in unique_ph:
+            clean_pseudoheaders += ['%s: %s' % (header, unique_ph[header])]
+
+    clean_pseudoheaders.extend(repeatable_ph)
+
+    return message, newheaders, clean_pseudoheaders
 
 
 def launch_mbox_reader(cmd, url, http_proxy, timeout):
@@ -1234,8 +1147,8 @@ def exec_and_parse_bugscript(handler, bugscript, runner=os.system):
 
     fh, filename = TempFile()
     fh.close()
-    rc = runner('LC_ALL=C %s %s %s' % (handler, pipes.quote(bugscript),
-                                          pipes.quote(filename)))
+    rc = runner('LC_ALL=C %s %s %s' % (handler, shlex.quote(bugscript),
+                                          shlex.quote(filename)))
 
     isheaders = False
     ispseudoheaders = False
@@ -1395,7 +1308,7 @@ def is_security_update(pkgname, pkgversion):
     #
     # This check is not sufficient to detect security updates reliably,
     # since other stable updates also use the same version pattern.
-    regex = re.compile('(\+|~)deb(\d+)u(\d+)')
+    regex = re.compile(r'(\+|~)deb(\d+)u(\d+)')
     secversion = regex.search(pkgversion)
     if not secversion:
         return False
@@ -1408,7 +1321,7 @@ def is_security_update(pkgname, pkgversion):
     # them are distributed through the normal channels as part of a
     # stable release update.
     try:
-        p = apt.Cache()[pkgname]
+        p = _apt_cache[pkgname]
         if 'Debian-Security' in [o.label for o in
                         p.versions[pkgversion].origins]:
             return True
