@@ -2,12 +2,16 @@
 import unittest
 from unittest import mock
 
+import pytest
+
 from reportbug import utils
+from reportbug import mailer
 import os.path
 import platform
-from nose.plugins.attrib import attr
 import debianbts
 import subprocess
+import email
+import textwrap
 
 
 class TestUtils(unittest.TestCase):
@@ -119,7 +123,7 @@ class TestPackages(unittest.TestCase):
         self.assertIsNotNone(depends)
         self.assertIsNotNone(maintainer)
         self.assertTrue(installed)
-        self.assertEqual(origin, 'debian')
+        self.assertIsNone(origin)
         self.assertEqual(priority, 'required')
         self.assertIsNotNone(desc)
         self.assertIsNotNone(fulldesc)
@@ -286,6 +290,13 @@ class TestSourcePackages(unittest.TestCase):
         src = utils.get_source_name('reportbug-bugfree')
         self.assertIsNone(src)
 
+        # The 'astroid' binary package belongs to the 'astroidmail'
+        # source package. get_source_name() must not return the
+        # 'astroid' source package here (which builds the
+        # python3-astroid binary package)
+        src = utils.get_source_name('astroid')
+        self.assertEqual(src, 'astroidmail')
+
     def test_get_source_package(self):
         src = 'reportbug'
         binpkgs = utils.get_source_package(src)
@@ -344,35 +355,13 @@ class TestSystemInformation(unittest.TestCase):
         os.path.islink = mock.MagicMock(return_value=False)
         init = utils.get_init_system()
         print(init)
-        self.assertTrue(init.startswith('sysvinit'))
+        self.assertTrue(init.startswith('runit'))
         os.path.isfile = __save1
         os.path.islink = __save2
         del __save1
         del __save2
 
 
-class TestMua(unittest.TestCase):
-    def test_mua_is_supported(self):
-
-        for mua in ('mh', 'nmh', 'gnus', 'mutt', 'claws-mail'):
-            self.assertTrue(utils.mua_is_supported(mua))
-
-        self.assertFalse(utils.mua_is_supported('mua-of-my-dreams'))
-
-    def test_mua_exists(self):
-
-        for mua in ('mh', 'nmh', 'gnus', 'mutt', 'claws-mail'):
-            if not utils.mua_exists(mua):
-                self.fail("%s MUA program not available" % mua)
-
-    def test_mua_name(self):
-
-        for mua in ('mh', 'nmh', 'gnus', 'mutt', 'claws-mail'):
-            self.assertIsInstance(utils.mua_name(mua), utils.Mua)
-
-        self.assertEqual(utils.mua_name('mua-of-my-dreams'), 'mua-of-my-dreams')
-
-
 class TestBugreportBody(unittest.TestCase):
     def test_get_dependency_info(self):
 
@@ -416,12 +405,22 @@ class TestBugreportBody(unittest.TestCase):
 Package: release.debian.org
 User: release.debian.org@packages.debian.org
 Usertags: unblock
+random text between pseudoheader lines
+Justification: line with too long content
+ so there is a continuation line
 Severity: normal
 Morph: cool
 Control: testcontrol1
+source: reportbug
 Control: testcontrol2
 Continuation:
  header
+X-Debbugs-CC: debian-reportbug@lists.debian.org
+x-debbugs-cC: root@localhost
+
+some text before further head-like line
+Version: 2.1.3
+tags: ftbfs
 
 Please unblock package reportbug
 
@@ -439,7 +438,12 @@ Kernel: Linux 2.6.31-1-amd64 (SMP w/4 CPU cores)
 Locale: LANG=en_US.UTF-8, LC_CTYPE=en_US.UTF-8 (charmap=UTF-8)
 Shell: /bin/sh linked to /bin/bash"""
         header = ['X-Debbugs-CC: reportbug@packages.qa.debian.org']
-        pseudos = ['Morph: cool', 'Control: testcontrol1', 'Control: testcontrol2']
+        pseudos = ['Morph: cool',
+                'Control: testcontrol1',
+                'Control: testcontrol2',
+                #'Control: testcontrol7',
+                #'Breaks: other',
+                ]
         rtype = 'debbugs'
         body, headers, pseudo = utils.cleanup_msg(message, header, pseudos,
                                                   rtype)
@@ -465,7 +469,47 @@ Shell: /bin/sh linked to /bin/bash"""
         for ph in pseudos:
             self.assertIn(ph, pseudo)
 
-    @attr('network')  # marking the test as using network
+        cleanheaders = [('X-Debbugs-CC', 'reportbug@packages.qa.debian.org'),
+                ('Subject', 'unblock: reportbug/4.12.6'),
+                ('Continuation', '\n header')
+                ]
+        cleanpseudos = ['Package: release.debian.org',
+                'Source: reportbug',
+                'Severity: normal',
+                'Justification: line with too long content',
+                'User: release.debian.org@packages.debian.org',
+                'Usertags: unblock',
+                'X-Debbugs-Cc: debian-reportbug@lists.debian.org, root@localhost',
+                'Morph: cool',
+                'Control: testcontrol1',
+                'Control: testcontrol2',
+                ]
+        cleanmessage = """some text before further head-like line
+Version: 2.1.3
+tags: ftbfs
+
+Please unblock package reportbug
+
+(explain the reason for the unblock here)
+
+unblock reportbug/4.12.6
+
+-- System Information:
+Debian Release: squeeze/sid
+  APT prefers unstable
+  APT policy: (500, 'unstable'), (1, 'experimental')
+Architecture: amd64 (x86_64)
+
+Kernel: Linux 2.6.31-1-amd64 (SMP w/4 CPU cores)
+Locale: LANG=en_US.UTF-8, LC_CTYPE=en_US.UTF-8 (charmap=UTF-8)
+Shell: /bin/sh linked to /bin/bash
+"""
+
+        self.assertEqual(headers, cleanheaders)
+        self.assertEqual(pseudo, cleanpseudos)
+        self.assertEqual(body, cleanmessage)
+
+    @pytest.mark.network  # marking the test as using network
     def test_generate_blank_report(self):
 
         report = utils.generate_blank_report('reportbug', '1.2.3', 'normal',
@@ -550,9 +594,9 @@ class TestConfig(unittest.TestCase):
             self.assertIn(conf, args)
             self.assertEqual(desired_conf[conf], args[conf])
 
-        # mua returns an instance of utils.Mua, need to check differently
+        # mua returns an instance of mailer.Mua, need to check differently
         self.assertIn('mua', args)
-        self.assertIsInstance(args['mua'], utils.Mua)
+        self.assertIsInstance(args['mua'], mailer.Mua)
 
     def test_bts579891(self):
         lex = utils.our_lex('realname "Paul \\"TBBle\\" Hampson"', posix=True)
